==> img0ch-2.1.2.tar.bz2: img0ch/_template/default/index.cs <==
<html>
<head>
<!--nobanner-->
<title><?cs var:BBS_TITLE ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<!--meta.txto͕-->
<?cs var:META ?>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<!--
jQuery(function () {
    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
    jQuery("form.comment").submit(function () {
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
        jQuery("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-->
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:BBS_BG_COLOR ?>" text="<?cs var:BBS_TEXT_COLOR ?>" link="<?cs var:BBS_LINK_COLOR ?>" alink="<?cs var:BBS_ALINK_COLOR ?>" vlink="<?cs var:BBS_VLINK_COLOR ?>" background="<?cs var:BBS_BG_PICTURE ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs var:BBS_TITLE_LINK ?>"><img src="<?cs var:BBS_TITLE_PICTURE ?>" border="0" /></a><?cs else ?><img src="<?cs var:BBS_TITLE_PICTURE ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<!--[J[\-->
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_MENU_COLOR ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <b><big><?cs var:BBS_SUBTITLE ?></big></b>
     </td>
     <td align="right">
      <a href="#menu"></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <?cs var:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align=center>
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<!--L\-->
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><br><?cs /if ?>

<!--Xbhꗗ\-->
<a name="menu" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_MAKETHREAD_COLOR ?>">
 <tr>
  <td>
   <small>
   <?cs each:item = Threads ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>:</a> <?cs var:item.subject ?> <a href="#<?cs var:item.index ?>">(<?cs var:item.res ?>)</a>
   <?cs /each ?>
   <?cs each:item = Stored ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>: <?cs var:item.subject ?> (<?cs var:item.res ?>)</a>
   <?cs /each ?>
   <div align="right"><b><a href="<?cs var:BBSURI ?>/subback.html">Xbhꗗ͂</a></b></div>
   </small>
  </td>
 </tr>
</table><br>
<!--Xbhꗗ\̋؂-->

<!--Xbh\-->
<?cs each:t = Threads ?>
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_THREAD_COLOR ?>">
 <tr>
  <td>
   <dl>
   <a name="<?cs var:t.index ?>" />
   <div align="right"><a href="#menu"></a><a href="#<?cs var:t.up ?>"></a><a href="#<?cs var:t.down ?>"></a></div>
   <b>y<?cs var:index ?>:<?cs var:res ?>z<font size="+2" color="<?cs var:BBS_SUBJECT_COLOR ?>"><?cs var:t.subject ?></font></b>
<!--XWJ\-->
   <?cs each:r = t.Thread ?><dt><?cs var:r.resno ?> OF<?cs if:r.mail ?><a href="mailto:<?cs var:r.mail ?>"><b><?cs var:r.name ?></b></a><?cs else ?><b><font color="<?cs var:BBS_NAME_COLOR ?>"><?cs var:r.name ?></font></b><?cs /if ?></b>F<?cs var:r.date ?></dt><dd><?cs var:r.text ?><br><br></dd>
   <?cs /each ?>
<!--XWJ\̋؂-->
   <form class="comment" method="POST" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <input type="hidden" name="bbs" value="<?cs var:BBS ?>">
   <input type="hidden" name="key" value="<?cs var:t.key ?>">
   <input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
   <input type="submit" value="" name="submit">
 OF<input type="text" name="FROM" size="19"> E-mailF<input type="text" name="mail" size="19"><br><ul>
<!--t@CI\(BBS_MODEpicturȅꍇ)-->
   <?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="74"><br><?cs /if ?>
<textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
<b><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/">Sǂ</a>
<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/l50">ŐV50</a>
<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/1-100">1-100</a>
<a href="#top">̃gbv</a> <a href="./index.html">[h</a>
   </ul>
   </form>
   </dl>
  </td>
 </tr>
</table><br>
<?cs /each ?>
<!--Xbh\̋؂-->

<!--tH[\-->
<form class="comment" method="POST" action="<?cs var:CGIURI ?>/bbs.cgi">
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_MAKETHREAD_COLOR ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br>
<?cs if:BBS_PASSWORD_CHECK ?>
   <input type="submit" value=" VKXbh쐬ʂ "><br>
   <input type="hidden" name="bbs" value="<?cs var:BBS ?>">
   <input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
   <input type="hidden" name="FROM" value="">
   <input type="hidden" name="mail" value="">
<?cs else ?>
   <center>
   <input type="hidden" name="bbs" value="<?cs var:BBS ?>">
   <input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
   <table border=0>
    <tr>
     <td>
      ^CgF<input type="text" name="subject" size=25>@<input type="submit" value="VKXbh쐬"><br>
      O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
      E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
<!--t@CI\(threadW[L̏ꍇ)-->
      <?cs if:UploadableFromThread ?><input type="file" name="file" size="80"><br><?cs /if ?>
      <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
     </td>
    </tr>
   </table>
   </center>
   <?cs var:html_escape(VERSION) ?>
<?cs /if ?>
  </td>
 </tr>
</table>
</form>
<?cs var:FOOT ?>
</center>
</body>
</html>

==> img0ch-2.1.3.tar.bz2: img0ch/_template/default/index.cs <==
<html>
<head>
<!--nobanner-->
<title><?cs var:BBS_TITLE ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<!--
jQuery(function () {
    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
    jQuery("form.comment").submit(function () {
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
        jQuery("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-->
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:BBS_BG_COLOR ?>" text="<?cs var:BBS_TEXT_COLOR ?>" link="<?cs var:BBS_LINK_COLOR ?>" alink="<?cs var:BBS_ALINK_COLOR ?>" vlink="<?cs var:BBS_VLINK_COLOR ?>" background="<?cs var:BBS_BG_PICTURE ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs var:BBS_TITLE_LINK ?>"><img src="<?cs var:BBS_TITLE_PICTURE ?>" border="0" /></a><?cs else ?><img src="<?cs var:BBS_TITLE_PICTURE ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<!--[J[\-->
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_MENU_COLOR ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <b><big><?cs var:BBS_SUBTITLE ?></big></b>
     </td>
     <td align="right">
      <a href="#menu"></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <?cs var:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align=center>
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<!--L\-->
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><br><?cs /if ?>

<!--Xbhꗗ\-->
<a name="menu" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_MAKETHREAD_COLOR ?>">
 <tr>
  <td>
   <small>
   <?cs each:item = Threads ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>:</a> <?cs var:item.subject ?> <a href="#<?cs var:item.index ?>">(<?cs var:item.res ?>)</a>
   <?cs /each ?>
   <?cs each:item = Stored ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>: <?cs var:item.subject ?> (<?cs var:item.res ?>)</a>
   <?cs /each ?>
   <div align="right"><b><a href="<?cs var:BBSURI ?>/subback.html">Xbhꗗ͂</a></b></div>
   </small>
  </td>
 </tr>
</table><br>
<!--Xbhꗗ\̋؂-->

<!--Xbh\-->
<?cs each:t = Threads ?>
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_THREAD_COLOR ?>">
 <tr>
  <td>
   <dl>
   <a name="<?cs var:t.index ?>" />
   <div align="right"><a href="#menu"></a><a href="#<?cs var:t.up ?>"></a><a href="#<?cs var:t.down ?>"></a></div>
   <b>y<?cs var:index ?>:<?cs var:res ?>z<font size="+2" color="<?cs var:BBS_SUBJECT_COLOR ?>"><?cs var:t.subject ?></font></b>
<!--XWJ\-->
   <?cs each:r = t.Thread ?><dt><?cs var:r.resno ?> OF<?cs if:r.mail ?><a href="mailto:<?cs var:r.mail ?>"><b><?cs var:r.name ?></b></a><?cs else ?><b><font color="<?cs var:BBS_NAME_COLOR ?>"><?cs var:r.name ?></font></b><?cs /if ?></b>F<?cs var:r.date ?></dt><dd><?cs var:r.text ?><br><br></dd>
   <?cs /each ?>
<!--XWJ\̋؂-->
   <form class="comment" method="POST" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <input type="hidden" name="bbs" value="<?cs var:BBS ?>">
   <input type="hidden" name="key" value="<?cs var:t.key ?>">
   <input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
   <input type="submit" value="" name="submit">
 OF<input type="text" name="FROM" size="19"> E-mailF<input type="text" name="mail" size="19"><br><ul>
<!--t@CI\(BBS_MODEpicturȅꍇ)-->
   <?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="74"><br><?cs /if ?>
<textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
<b><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/">Sǂ</a>
<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/l50">ŐV50</a>
<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/1-100">1-100</a>
<a href="#top">̃gbv</a> <a href="./index.html">[h</a>
   </ul>
   </form>
   </dl>
  </td>
 </tr>
</table><br>
<?cs /each ?>
<!--Xbh\̋؂-->

<!--tH[\-->
<form class="comment" method="POST" action="<?cs var:CGIURI ?>/bbs.cgi">
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:BBS_MAKETHREAD_COLOR ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br>
<?cs if:BBS_PASSWORD_CHECK ?>
   <input type="submit" value=" VKXbh쐬ʂ "><br>
   <input type="hidden" name="bbs" value="<?cs var:BBS ?>">
   <input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
   <input type="hidden" name="FROM" value="">
   <input type="hidden" name="mail" value="">
<?cs else ?>
   <center>
   <input type="hidden" name="bbs" value="<?cs var:BBS ?>">
   <input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
   <table border=0>
    <tr>
     <td>
      ^CgF<input type="text" name="subject" size=25>@<input type="submit" value="VKXbh쐬"><br>
      O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
      E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
<!--t@CI\(threadW[L̏ꍇ)-->
      <?cs if:UploadableFromThread ?><input type="file" name="file" size="80"><br><?cs /if ?>
      <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
     </td>
    </tr>
   </table>
   </center>
   <?cs var:html_escape(VERSION) ?>
<?cs /if ?>
  </td>
 </tr>
</table>
</form>
<?cs var:FOOT ?>
</center>
</body>
</html>
